<?php
/**
 * Admin area functionality.
 *
 * @package TotalWebTool
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit();
}

add_action( 'admin_menu', 'totalwebtool_admin_menu' );
add_action( 'add_meta_boxes', 'totalwebtool_add_editor_box' );
add_action( 'admin_enqueue_scripts', 'totalwebtool_enqueue_css_js' );
add_action( 'wp_ajax_totalwebtool_request', 'totalwebtool_ajax_request_handler' );

/**
 * Adds submenu for Admin > Settings
 */
function totalwebtool_admin_menu() {
	add_submenu_page(
		'options-general.php',
		'TotalWebTool.io Settings',
		'TotalWebTool',
		'manage_options',
		'totalwebtool-plugin',
		'totalwebtool_admin_init'
	);
}

/**
 * WP admin page for managing TotalWebTool settings.
 */
function totalwebtool_admin_init() {
	$current_user = wp_get_current_user();
	if ( ! isset( $current_user ) || ! in_array( 'administrator', $current_user->roles, true ) ) {
		return;
	}

	add_option(
		'totalwebtool_settings',
		array(
			'apiToken' => '',
		)
	);
	totalwebtool_handle_settings();

	$settings = get_option( 'totalwebtool_settings', array() );

	?>
	<h1>TotalWebTool Settings</h1>
	<form method="post">
		<table class="form-table" role="presentation">
			<tbody>
				<tr>
					<th>API Key</th>
				<td>
					<input name="api_key" type="text" value="<?php echo esc_attr( $settings['apiToken'] ); ?>" />
				</td>
				</tr>
			</tbody>
		</table>
		<p class="submit">
			<?php wp_nonce_field( -1, 'totalwebtool-settings-nonce' ); ?>
			<input type="submit" name="submit" id="submit" class="button button-primary" value="Save Settings" />
		</p>
	</form>

	<?php

}

/**
 * Form submission handler for TotalWebTool settings.
 */
function totalwebtool_handle_settings() {
	if ( count( $_POST ) && isset( $_POST['totalwebtool-settings-nonce'] ) ) {
		if ( ! ( wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['totalwebtool-settings-nonce'] ) ) ) ) ) {
			die( 'Invalid nonce.' );
		}
		$settings = get_option( 'totalwebtool_settings', array() );
		$settings = array_merge(
			$settings,
			array(
				'apiToken' => sanitize_text_field( $_POST['api_key'] ),
			)
		);

		update_option( 'totalwebtool_settings', $settings );
	}
}

function totalwebtool_add_editor_box() {
	add_meta_box(
		'totalwebtool_editor_box',
		'<span style="display: inline-flex; align-items: center"><img alt="" aria-hidden="true" width="20" height="20" src="https://totalwebtool.com/assets/images/favicon.png?rel=wpadmin" />TotalWebTool Analysis</span>',
		'totalwebtool_editor_box',
		'page'
	);
}

function totalwebtool_editor_box() {
	echo '<button id="totalwebtool-analyze" type="button" aria-disabled="false">Analyze this page</button>
	<div class="totatwebtool-lds-spinner"><div></div><div></div><div></div><div></div><div></div><div></div><div></div><div></div><div></div><div></div><div></div><div></div></div>';
}

function totalwebtool_ajax_request_handler() {
	$pageUrl = $_POST['pageUrl'];
	$response = totalwebtool_analyze(['url' => $pageUrl]);
	wp_send_json($response);
}  

function totalwebtool_enqueue_css_js() {
	//link css file in header
	wp_enqueue_style(
		'analyzer_style',
		plugin_dir_url(__FILE__)."totalwebtool.css",
		[],
		filemtime(plugin_dir_path(__FILE__) . '/totalwebtool.css')
	);

	//add js script to wordpress footer
	wp_enqueue_script(
		'analyzer_script',
		plugin_dir_url(__FILE__)."totalwebtool.js",
		['jquery', 'jquery-effects-core'],
		"",
		true
	);

	$totalwebtool_nonce = wp_create_nonce("totalwebtool_analyze_string");

	//inject variables into js script
	wp_add_inline_script(
		"analyzer_script",
		"const pageObject =".
		json_encode([
			'pageUrl' => get_permalink(get_the_ID()),
			'check' => $totalwebtool_nonce,
			'totalwebtool_plugin_directory' => plugin_dir_url(__FILE__)
		]) ."",
		"before"
	);
}