<?php
/**
 * Library functions
 *
 * @package TotalWebTool
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit();
}

/**
 * Debugging helper function.
 *
 * @param array ...$args List of values to log.
 */
function totalwebtool_debug( ...$args ) {
	// phpcs:disable WordPress.PHP.DevelopmentFunctions
	error_log( gmdate( 'Y-m-d H:i:s' ) . ' - ' . print_r( $args, true ) );
	// phpcs:enable
}

/**
 * Makes API request to TotalWebTool API
 *
 * @param array $params array of request body params.
 * @throws Exception When there is a WP_Error for request or json_decode issue.
 */
function totalwebtool_analyze( $params ) {
	check_ajax_referer("totalwebtool_analyze_string", "security");
	$settings = get_option( 'totalwebtool_settings' );

	$headers = array();
	if ( $settings['apiToken'] ) {
		$headers['Authorization'] = $settings['apiToken'];
	}

	$totalwebtool_api_url = get_option('totalwebtool_api_url') ?: 'https://totalwebtool.com/api/v1/analyze';
	$res = wp_remote_post(
		$totalwebtool_api_url,
		array(
			'headers'    => $headers,
			'body'       => $params,
			'user-agent' => 'TotalWebTool Wordpress Plugin / ' . get_bloginfo( 'version' ),
		)
	);	

	if ( is_wp_error( $res ) ) {
		throw new Exception( implode( '. ', $res->errors ) );
	}

	$body = $res['body'];
	$json = json_decode( $body );
	if ( json_last_error() ) {
		throw new Exception( 'Unable to parse json response' );
	}

	return $json;
}
