jQuery( function ( $ ) {
    $("#totalwebtool-analyze").on("click", function(e) {
        var analyzerTool = $(this);
        e.preventDefault();
        $(analyzerTool).hide();
        $(".totatwebtool-lds-spinner").css('display', 'inline-block');
        $.ajax({
            url: ajaxurl,
            type: "POST",
            data: {
                action: "totalwebtool_request",
                security: pageObject.check,
                pageUrl: pageObject.pageUrl
            },
            success: function(response) {
                var render = "";
                $(".totatwebtool-lds-spinner").css('display', 'none');
                $(analyzerTool).show();

				if (!response.success && response.error) {
					$('#totalwebtool_editor_box>.inside').append(`<p style="color: #a00">${response.error}</p>`);
					return;
				} else if (!response.success) {
					$('#totalwebtool_editor_box>.inside').append(`<p style="color: #a00">An unexpected error occurred. Please wait a few moments then try again.</p>`);
					return;
				}

                var results = response.report.results;
                if (results.length > 0) {
                    results.sort(function(a,b) {
                        if (a.category === b.category) {
                            return b.score - a.score;
                        }
                        return a.category < b.category; 
                    });
                    render = createResultTable(results);           
                } else {
                    if ($(".totalwebtool-success").length) {
                        $(".totalwebtool-success").remove();
                    }
                    render = `<p class='totalwebtool-success'>
                            <span class='dashicons dashicons-warning'></span> 
                            Success! No issues were found on this page. 
                        </p>`;
                }
                if ($(".totalwebtool-accordion").length) {
                    $(".totalwebtool-accordion").remove();
                }
                $('#totalwebtool_editor_box>.inside').append(render);
                $('.interface-interface-skeleton__content')
                    .scrollTop(
                        $('.editor-styles-wrapper').outerHeight() + $('#totalwebtool_editor_box').outerHeight()
                        -
                        $('.interface-interface-skeleton__content').outerHeight() 
                    );
            },
            error: function(xhr) {
                $(".totatwebtool-lds-spinner").css('display', 'none');
                $(analyzerTool).show();
                if ($(".totalwebtool-error").length) {
                    $(".totalwebtool-error").remove();
                }
                render = `<p class='totalwebtool-error'>
                        <span class='dashicons dashicons-warning'></span> 
                        Error! ` + xhr.statusText + 
                    `</p>`;
                render += xhr.responseText;
                $('#totalwebtool_editor_box>.inside').append(render);
            }
        });
    });

    function createResultTable(results) {
        var categories = [];
        var render = "";

        function getIcon(value) {
            var icon = "totalwebtool-fire-outline-normal.svg";
            if (value > 30) {
                icon = "totalwebtool-fire-outline-warning.svg";
            }
            if (value >= 50) {
                icon = "totalwebtool-fill-fire-danger.svg";
            }
            if (value >= 75) {
                icon = "totalwebtool-fill-fire-critical.svg";
            }
            return icon;
        }

        var catObject = {
            acc: 'Accessibility',
            sec: 'Security',
            perf: 'Performance',
            seo: 'Search Engine Optimization (SEO)',
            gen: 'General',
            code: 'Code',
            ux: 'User Experience (UX)'
        }
        
        render = "<dl class='accordion totalwebtool-accordion'>";
        results.forEach(function(result, i) {
            if(categories.indexOf(result.category) === -1) {
                var defaultOpenClass = i === 0 ? "totalwebtool-acc-open" : "";
                if (categories.length > 0) {
                    render += "</tbody>";
                    render += "</table>";
                }
                var iconClass = i === 0 ? "dashicons-arrow-up-alt2" : "dashicons-arrow-down-alt2"
                var category = result.category;
                categories.push(category);
                render += "<dt class='" 
                    + defaultOpenClass + "'> <span class='totalwebtool-panel-header'>"
                    +catObject[category].toUpperCase() 
                    +" </span> <span class='first-accordion-icon dashicons " 
                    + iconClass + "'></span></dt>";
                render += createTableHead(i);
            }
            render += createTableRow(result, getIcon);
        });
        render += "</tbody>";
        render += "</table>";
        render += "</dl>";

        return render;
    }

    function createTableRow(row, iconPicker) {
        var columns = ["score", "problem", "solution"]
        render = "<tr>";
        columns.forEach(function(column) {
            var iconStyle = column === "score" ? " style='text-align:center;'" : "";
            render += "<td" + iconStyle + ">";
            if (column === "score") {
                render += "<img src='" 
                    + pageObject.totalwebtool_plugin_directory + iconPicker(row[column]) 
                    + "' alt='flame-icon'>";
            } else {
                if (column === "problem" && row["value"] && row["value"] !== "") {
                    render += "<div class='totalwebtool-issue-accordion'>"
                }

                render += row[column];

                if(column === "problem") {
                    if (row["value"] && row["value"] !== "") {
                        render += "<span class='totalwebtool-issue-accordion-icon dashicons dashicons-arrow-down-alt2'></span></div>";
                        render += "<div class='totalwebtool-issue-value'><code>" + row["value"] + "</code>";
                    }

                    render += "<div class='totalwebtool-phone-solution'><span><b>Solution </b></span> <span>" + row["solution"] + "</span></div></div>";
                }

            }
            render += "</td>";
        })
        render += "</tr>";
        return render;
    }

    function createTableHead(pos) {
        var headers = {
            "Rating": 5,
            "Issue": 35, 
            "Solution": 60
        };
        var tbStyle = pos !== 0 ? " style='display:none;'" : "";
        var render = "<table" + tbStyle + ">";
        render += "<tbody width='100%'>";
        render += "<tr>";
        for(let header in headers) {
            render += "<th width='"+headers[header]+"%' >";
            render += header === "Rating" ? " " : header;
            render += "</th>";
        };
        render += "</tr>";
        return render;
    }

    $("#totalwebtool_editor_box").click(function(e){
        if(
            e.target.nodeName === "DT" 
            || (
                e.target.classList.contains("first-accordion-icon") 
                || e.target.classList.contains("totalwebtool-panel-header")
            )
        ) {
            var panel = $(e.target);
            if(e.target.nodeName === "SPAN") {
                panel = panel.parent();
            }
            var closeOnly = panel.hasClass("totalwebtool-acc-open") ? true : false;

            $(".totalwebtool-accordion > dt").removeClass("totalwebtool-acc-open");
            $(".totalwebtool-accordion dt span.first-accordion-icon")
                .removeClass()
                .addClass("dashicons dashicons-arrow-down-alt2 first-accordion-icon");
            $(".totalwebtool-accordion > table").hide();
            if (!closeOnly) {
                panel.next().slideDown();
                panel.addClass("totalwebtool-acc-open");
                panel.find("span.first-accordion-icon")
                    .removeClass("dashicons-arrow-down-alt2")
                    .addClass("dashicons-arrow-up-alt2");
            }
            $('.interface-interface-skeleton__content')
                .scrollTop(
                    $('.editor-styles-wrapper').outerHeight() + $('#totalwebtool_editor_box').outerHeight() + panel.offset().top
                    -
                    $('.interface-interface-skeleton__content').outerHeight() 
                );
            return false;
        }
    });

    $("#totalwebtool_editor_box").click(function(e){
        if (e.target.classList.contains("totalwebtool-issue-accordion-icon")) {
            var icon = $(e.target);
            if (icon.hasClass("dashicons-arrow-up-alt2")) {
                icon.removeClass("dashicons-arrow-up-alt2");
                icon.addClass("dashicons-arrow-down-alt2");
                icon.parent().next().slideUp();
            } else {
                icon.removeClass("dashicons-arrow-down-alt2");
                icon.addClass("dashicons-arrow-up-alt2");
                icon.parent().next().slideDown();
            }
        }
    });

});
